featureflags package
====================

Subpackages
-----------

.. toctree::

    featureflags.client
    featureflags.evaluation
    featureflags.rest

Module contents
---------------

.. automodule:: featureflags
    :members:
    :undoc-members:
    :show-inheritance:
